@@ -1,6 +1,7 @@
 from ..cases import send_checks_changed
 from ..discovery import get_registry
 from ..utils import fix_check
+from ..dtos import UserIdType, UserCheckStates, UserCheckDTO, UserCheckStateDTO
 
 
 __all__ = 'AdminBaseMixin', 'AdminInlineBaseMixin',
@@ -19,9 +20,15 @@ class AdminBaseMixin:
         return super().get_readonly_fields(request, obj=obj)
 
     def save_model(self, request, obj, form, change):
+        if obj.pk:
+            previous_state = obj.__class__.objects.filter(pk=obj.pk)
+            olds = UserCheckStateDTO.from_checks([
+                UserCheckDTO.from_model(check) for check in previous_state
+            ])
+
         obj = fix_check(get_registry(), obj)
         super().save_model(request, obj, form, change)
-        send_checks_changed([obj])
+        send_checks_changed([obj], previous_states=olds)
 
 
 class AdminInlineFormsetBaseMixin:
@@ -35,8 +42,11 @@ class AdminInlineFormsetBaseMixin:
         return super().save_existing(form, instance, commit=commit)
 
     def save(self):
+        olds = UserCheckStateDTO.from_checks([
+            UserCheckDTO.from_model(check) for check in self.queryset
+        ])
         saved = super().save()
-        send_checks_changed(saved)
+        send_checks_changed(saved, previous_states=olds)
 
         return saved
 
