@@ -1,4 +1,4 @@
-from typing import Dict, Optional, Sequence, Tuple, Union
+from typing import Dict, List, Optional, Sequence, Tuple, Union
 from .registry import CheckDefinition, CheckRegistry
 from .dtos import UserIdType, UserCheckDTO
 from .models import UserCheck
